[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Documents Distributor - Documents client library for Python

[![API Version](https://img.shields.io/badge/api-v1.0.0-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.DocumentsDistributorDocuments)](https://pypi.org/project/fds.sdk.DocumentsDistributorDocuments/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Documents APIs that provide filings such as Global Filings and XML files such as StreetAccount

  Global Filings API provides the capability to search and download filings documents from various exchanges around the world. This API will provide access to the full history and the ability to search by date and dataset(source). It does not provide real-time updates to the filings documents. Filings providers currently include EDGAR 
  
  Note: The real-time updates to the filing documents will be available within week to ten days and per request able to query up to 8 days of data
        
  
  StreetAccount XML API provides access to historical StreetAccount (SA) news. SA provides a summary for various corporate and market news written by journalist with background in financial markets.

  The API delivers SA stories in XML format based on user-specified date input parameters. When the API request is completed, output files will be made available back to the users through a secure URL. This API has three endpoints (1) Request Files (2) Check Status (3) Get Files.
  
  This API only supports adhoc requests to retrieve historical files and does not support real-time files and if require real-time push should consider the other three methods (pushed via SFTP, to QNT account, or users Azure Storage)

 Both historical and real-time Street Account news is also delivered via SFTP, to users QNT account, or users Azure Storage.

Files delivered contain both metadata and content body in each file. This eliminates the need to make multiple requests through multiple services to get all the information.

News API provides access to historical news. This provides a summary for various corporate and market news written by journalist with background in financial markets.

The API delivers  stories in different format based on user-specified date input parameters. When the API request is completed, output files will be made available back to the users through a secure URL. This API has three endpoints (1) Request Files (2) Check Status (3) Get Files  
 

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 0.21.14
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.DocumentsDistributorDocuments==0.21.14
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.DocumentsDistributorDocuments==0.21.14
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.DocumentsDistributorDocuments
from fds.sdk.DocumentsDistributorDocuments.api import global_filings_api_api
from fds.sdk.DocumentsDistributorDocuments.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.DocumentsDistributorDocuments.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = global_filings_api_api.GlobalFilingsAPIApi(api_client)
    start_date = dateutil_parser('1970-01-01').date() # date | The earliest date the API should fetch for. Dates can be YYYY-MM-DD format
    end_date = dateutil_parser('1970-01-01').date() # date | The date after upto eight days of the earliest date given the API should fetch for. Dates can be YYYY-MM-DD format

    try:
        # Retrieve filings within FactSet coverage
        # example passing only required values which don't have defaults set
        api_response = api_instance.global_filings_v1_list_files_get(start_date, end_date)

        pprint(api_response)
    except fds.sdk.DocumentsDistributorDocuments.ApiException as e:
        print("Exception when calling GlobalFilingsAPIApi->global_filings_v1_list_files_get: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Retrieve filings within FactSet coverage
    #     api_response, http_status_code, response_headers = api_instance.global_filings_v1_list_files_get_with_http_info(start_date, end_date)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.DocumentsDistributorDocuments.ApiException as e:
    #     print("Exception when calling GlobalFilingsAPIApi->global_filings_v1_list_files_get: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Retrieve filings within FactSet coverage
    #     async_result = api_instance.global_filings_v1_list_files_get_async(start_date, end_date)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.DocumentsDistributorDocuments.ApiException as e:
    #     print("Exception when calling GlobalFilingsAPIApi->global_filings_v1_list_files_get: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Retrieve filings within FactSet coverage
    #     async_result = api_instance.global_filings_v1_list_files_get_with_http_info_async(start_date, end_date)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.DocumentsDistributorDocuments.ApiException as e:
    #     print("Exception when calling GlobalFilingsAPIApi->global_filings_v1_list_files_get: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.DocumentsDistributorDocuments

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.DocumentsDistributorDocuments

configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.DocumentsDistributorDocuments

configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.DocumentsDistributorDocuments

configuration = fds.sdk.DocumentsDistributorDocuments.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/bulk-documents*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*GlobalFilingsAPIApi* | [**global_filings_v1_list_files_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/GlobalFilingsAPIApi.md#global_filings_v1_list_files_get) | **GET** /global-filings/v1/list-files | Retrieve filings within FactSet coverage
*NewsAPIApi* | [**asynch_news_v1_check_status_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsAPIApi.md#asynch_news_v1_check_status_get) | **GET** /asynch/news/v1/check-status | Returns the status and percentDone of the requested jobID and source
*NewsAPIApi* | [**asynch_news_v1_get_files_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsAPIApi.md#asynch_news_v1_get_files_get) | **GET** /asynch/news/v1/get-files | Returns the news filings for the specified daterange and source
*NewsAPIApi* | [**asynch_news_v1_request_files_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsAPIApi.md#asynch_news_v1_request_files_get) | **GET** /asynch/news/v1/request-files | Returns the jobID
*StreetAccountXMLAPIApi* | [**asynch_streetaccount_v1_check_status_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/StreetAccountXMLAPIApi.md#asynch_streetaccount_v1_check_status_get) | **GET** /asynch/streetaccount/v1/check-status | Returns the status and percentDone of the requested jobID
*StreetAccountXMLAPIApi* | [**asynch_streetaccount_v1_get_files_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/StreetAccountXMLAPIApi.md#asynch_streetaccount_v1_get_files_get) | **GET** /asynch/streetaccount/v1/get-files | Returns the SA XML files for the specified daterange
*StreetAccountXMLAPIApi* | [**asynch_streetaccount_v1_request_files_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/StreetAccountXMLAPIApi.md#asynch_streetaccount_v1_request_files_get) | **GET** /asynch/streetaccount/v1/request-files | Returns the jobID


## Documentation For Models

 - [Checkstatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/Checkstatus.md)
 - [CheckstatusResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/CheckstatusResponse.md)
 - [Checkstatusone](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/Checkstatusone.md)
 - [FilingsFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/FilingsFiles.md)
 - [FilingsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/FilingsResponse.md)
 - [Getfiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/Getfiles.md)
 - [GetfilesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/GetfilesResponse.md)
 - [Getfilesone](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/Getfilesone.md)
 - [IsPartialOne](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/IsPartialOne.md)
 - [MetaOne](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/MetaOne.md)
 - [NewsStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsStatus.md)
 - [NewscheckstatusResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewscheckstatusResponse.md)
 - [NewsgetfilesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsgetfilesResponse.md)
 - [NewsrequestfilesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/NewsrequestfilesResponse.md)
 - [PaginationOne](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/PaginationOne.md)
 - [RequestfilesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/RequestfilesResponse.md)
 - [Status](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/Status.md)
 - [StreetAccountStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorDocuments/v1/docs/StreetAccountStatus.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.DocumentsDistributorDocuments.apis and fds.sdk.DocumentsDistributorDocuments.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.DocumentsDistributorDocuments.api.default_api import DefaultApi`
- `from fds.sdk.DocumentsDistributorDocuments.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.DocumentsDistributorDocuments
from fds.sdk.DocumentsDistributorDocuments.apis import *
from fds.sdk.DocumentsDistributorDocuments.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

